@@ -1,19 +1,20 @@
 /*
- *  Copyright (c) Stephan Arts 2006-2010 <stephan@xfce.org>
- *
- *  This program is free software; you can redistribute it and/or modify
- *  it under the terms of the GNU General Public License as published by
- *  the Free Software Foundation; either version 2 of the License, or
- *  (at your option) any later version.
+ *  Copyright (c) Stephan Arts 2006-2012 <stephan@xfce.org>
  *
+ *  This program is free software; you can redistribute it and/or
+ *  modify it under the terms of the GNU General Public License
+ *  as published by the Free Software Foundation; either version 2
+ *  of the License, or (at your option) any later version.
+ * 
  *  This program is distributed in the hope that it will be useful,
  *  but WITHOUT ANY WARRANTY; without even the implied warranty of
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- *  GNU Library General Public License for more details.
- *
+ *  GNU General Public License for more details.
+ * 
  *  You should have received a copy of the GNU General Public License
  *  along with this program; if not, write to the Free Software
- *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+ *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
+ *  02110-1301, USA.
  */
 
 #ifndef __RISTRETTO_IMAGE_VIEWER_H__
@@ -61,13 +62,14 @@ struct _RsttoImageViewerClass
 {
     GtkWidgetClass  parent_class;
 
-    gboolean (* set_scroll_adjustments) (RsttoImageViewer *viewer,
-          GtkAdjustment     *hadjustment,
-          GtkAdjustment     *vadjustment);
+    gboolean (* set_scroll_adjustments) (
+            RsttoImageViewer *viewer,
+            GtkAdjustment     *hadjustment,
+            GtkAdjustment     *vadjustment);
 };
 
 GType
-rstto_image_viewer_get_type();
+rstto_image_viewer_get_type(void);
 
 GtkWidget *
 rstto_image_viewer_new ();
@@ -115,6 +117,11 @@ rstto_image_viewer_set_show_clock (
         RsttoImageViewer *viewer,
         gboolean value);
 
+gboolean
+rstto_image_viewer_is_busy (
+        RsttoImageViewer *viewer );
+
+
 G_END_DECLS
 
 #endif /* __RISTRETTO_IMAGE_VIEWER_H__ */
