@@ -1,19 +1,20 @@
 /*
- *  Copyright (c) Stephan Arts 2006-2011 <stephan@xfce.org>
- *
- *  This program is free software; you can redistribute it and/or modify
- *  it under the terms of the GNU General Public License as published by
- *  the Free Software Foundation; either version 2 of the License, or
- *  (at your option) any later version.
+ *  Copyright (c) Stephan Arts 2006-2012 <stephan@xfce.org>
  *
+ *  This program is free software; you can redistribute it and/or
+ *  modify it under the terms of the GNU General Public License
+ *  as published by the Free Software Foundation; either version 2
+ *  of the License, or (at your option) any later version.
+ * 
  *  This program is distributed in the hope that it will be useful,
  *  but WITHOUT ANY WARRANTY; without even the implied warranty of
  *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- *  GNU Library General Public License for more details.
- *
+ *  GNU General Public License for more details.
+ * 
  *  You should have received a copy of the GNU General Public License
  *  along with this program; if not, write to the Free Software
- *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+ *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
+ *  02110-1301, USA.
  */
 
 #include <config.h>
@@ -162,6 +163,8 @@ main(int argc, char **argv)
         GDK_THREADS_ENTER();
         gtk_main();
         GDK_THREADS_LEAVE();
+
+        g_object_unref (image_list);
     }
     else
     {
@@ -174,10 +177,10 @@ main(int argc, char **argv)
                     "preferences",
                     NULL);
         }
+        gtk_widget_destroy (window);
     }
 
     g_object_unref (settings);
-    g_object_unref (image_list);
 
     xfconf_shutdown();
 
